@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+
 import org.apache.maven.artifact.handler.ArtifactHandler;
 import org.apache.maven.artifact.handler.manager.ArtifactHandlerManager;
 import org.apache.maven.artifact.repository.ArtifactRepository;
@@ -36,6 +37,7 @@ import org.apache.maven.plugin.MojoFailureException;
 import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
+import org.apache.maven.plugins.dependency.utils.StringUtils;
 import org.apache.maven.project.DefaultProjectBuildingRequest;
 import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.repository.RepositorySystem;
@@ -48,7 +50,6 @@ import org.apache.maven.shared.transfer.dependencies.DefaultDependableCoordinate
 import org.apache.maven.shared.transfer.dependencies.DependableCoordinate;
 import org.apache.maven.shared.transfer.dependencies.resolve.DependencyResolver;
 import org.apache.maven.shared.transfer.dependencies.resolve.DependencyResolverException;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * Resolves a single artifact, eventually transitively, from the specified remote repositories. Caveat: will always
@@ -58,7 +59,7 @@ import org.codehaus.plexus.util.StringUtils;
 public class GetMojo extends AbstractMojo {
     private static final Pattern ALT_REPO_SYNTAX_PATTERN = Pattern.compile("(.+)::(.*)::(.+)");
 
-    @Parameter(defaultValue = "${session}", required = true, readonly = true)
+    @Component
     private MavenSession session;
 
     @Component
@@ -84,38 +85,6 @@ public class GetMojo extends AbstractMojo {
 
     private DefaultDependableCoordinate coordinate = new DefaultDependableCoordinate();
 
-    /**
-     * The groupId of the artifact to download. Ignored if {@link #artifact} is used.
-     */
-    @Parameter(property = "groupId")
-    private String groupId;
-
-    /**
-     * The artifactId of the artifact to download. Ignored if {@link #artifact} is used.
-     */
-    @Parameter(property = "artifactId")
-    private String artifactId;
-
-    /**
-     * The version of the artifact to download. Ignored if {@link #artifact} is used.
-     */
-    @Parameter(property = "version")
-    private String version;
-
-    /**
-     * The classifier of the artifact to download. Ignored if {@link #artifact} is used.
-     *
-     * @since 2.3
-     */
-    @Parameter(property = "classifier")
-    private String classifier;
-
-    /**
-     * The packaging of the artifact to download. Ignored if {@link #artifact} is used.
-     */
-    @Parameter(property = "packaging", defaultValue = "jar")
-    private String packaging = "jar";
-
     /**
      * Repositories in the format id::[layout]::url or just url, separated by comma. ie.
      * central::default::https://repo.maven.apache.org/maven2,myrepo::::https://repo.acme.com,https://repo.acme2.com
@@ -136,7 +105,7 @@ public class GetMojo extends AbstractMojo {
     private List<ArtifactRepository> pomRemoteRepositories;
 
     /**
-     * Download transitively, retrieving the specified artifact and all of its dependencies.
+     * Resolve transitively, retrieving the specified artifact and all of its dependencies.
      */
     @Parameter(property = "transitive", defaultValue = "true")
     private boolean transitive = true;
@@ -161,7 +130,7 @@ public class GetMojo extends AbstractMojo {
                     + "e.g. -Dartifact=org.apache.maven.plugins:maven-downloader-plugin:1.0");
         }
         if (artifact != null) {
-            String[] tokens = StringUtils.split(artifact, ":");
+            String[] tokens = artifact.split("\\s*:+\\s*");
             if (tokens.length < 3 || tokens.length > 5) {
                 throw new MojoFailureException("Invalid artifact, you must specify "
                         + "groupId:artifactId:version[:packaging[:classifier]] " + artifact);
@@ -188,7 +157,7 @@ public class GetMojo extends AbstractMojo {
 
         if (remoteRepositories != null) {
             // Use the same format as in the deploy plugin id::layout::url
-            String[] repos = StringUtils.split(remoteRepositories, ",");
+            String[] repos = remoteRepositories.split("\\s*,+\\s*");
             for (String repo : repos) {
                 repoList.add(parseRepository(repo, always));
             }
@@ -245,6 +214,7 @@ public class GetMojo extends AbstractMojo {
             }
 
             id = matcher.group(1).trim();
+
             if (!StringUtils.isEmpty(matcher.group(2))) {
                 layout = getLayout(matcher.group(2).trim());
             }
@@ -271,36 +241,53 @@ public class GetMojo extends AbstractMojo {
     }
 
     /**
+     * The groupId of the artifact to resolve. Ignored if {@link #artifact} is used.
+     *
      * @param groupId The groupId.
      */
+    @Parameter(property = "groupId")
     public void setGroupId(String groupId) {
         this.coordinate.setGroupId(groupId);
     }
 
     /**
+     * The artifactId of the artifact to resolve. Ignored if {@link #artifact} is used.
+     *
      * @param artifactId The artifactId.
      */
+    @Parameter(property = "artifactId")
     public void setArtifactId(String artifactId) {
         this.coordinate.setArtifactId(artifactId);
     }
 
     /**
+     * The version of the artifact to resolve. Ignored if {@link #artifact} is used.
+     *
      * @param version The version.
      */
+    @Parameter(property = "version")
     public void setVersion(String version) {
         this.coordinate.setVersion(version);
     }
 
     /**
+     * The classifier of the artifact to resolve. Ignored if {@link #artifact} is used.
+     *
      * @param classifier The classifier to be used.
+     *
+     * @since 2.3
      */
+    @Parameter(property = "classifier")
     public void setClassifier(String classifier) {
         this.coordinate.setClassifier(classifier);
     }
 
     /**
+     * The packaging of the artifact to resolve. Ignored if {@link #artifact} is used.
+     *
      * @param type packaging.
      */
+    @Parameter(property = "packaging", defaultValue = "jar")
     public void setPackaging(String type) {
         this.coordinate.setType(type);
     }
