@@ -26,6 +26,7 @@ import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.ArtifactUtils;
 import org.apache.maven.artifact.handler.manager.ArtifactHandlerManager;
@@ -61,7 +62,6 @@ import org.apache.maven.shared.transfer.dependencies.resolve.DependencyResolverE
 import org.apache.maven.shared.utils.logging.MessageBuilder;
 import org.apache.maven.shared.utils.logging.MessageUtils;
 import org.codehaus.plexus.util.FileUtils;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * When run on a project, remove the project dependencies from the local repository, and optionally re-resolve them.
@@ -88,10 +88,10 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
     /**
      * The current Maven project.
      */
-    @Parameter(defaultValue = "${project}", readonly = true, required = true)
+    @Component
     private MavenProject project;
 
-    @Parameter(defaultValue = "${session}", readonly = true, required = true)
+    @Component
     private MavenSession session;
 
     /**
@@ -297,11 +297,11 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
             return;
         }
 
-        if (!StringUtils.isEmpty(manualInclude)) {
+        if (!(manualInclude == null || manualInclude.isEmpty())) {
             manualIncludes = this.parseIncludes(manualInclude);
         }
         // If it's a manual purge, the only step is to delete from the local repo
-        if (manualIncludes != null && manualIncludes.size() > 0) {
+        if (manualIncludes != null && !manualIncludes.isEmpty()) {
             manualPurge(manualIncludes);
             return;
         }
@@ -378,16 +378,16 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
                 .a(theIncludes.size() != 1 ? "dependencies" : "dependency")
                 .a(" from ")
                 .strong(localRepository.getBasedir())
-                .toString());
+                .build());
 
         for (String gavPattern : theIncludes) {
-            if (StringUtils.isEmpty(gavPattern)) {
+            if (gavPattern == null || gavPattern.isEmpty()) {
                 getLog().debug("Skipping empty gav pattern");
                 continue;
             }
 
             String relativePath = gavToPath(gavPattern);
-            if (StringUtils.isEmpty(relativePath)) {
+            if (relativePath == null || relativePath.isEmpty()) {
                 getLog().debug("Skipping empty relative path for gav pattern: " + gavPattern);
                 continue;
             }
@@ -413,7 +413,7 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
      * @return the corresponding path
      */
     private String gavToPath(String gav) {
-        if (StringUtils.isEmpty(gav)) {
+        if (gav == null || gav.isEmpty()) {
             return null;
         }
 
@@ -449,14 +449,14 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
         }
 
         // The CLI includes/excludes overrides configuration in the pom
-        if (!StringUtils.isEmpty(this.include)) {
+        if (!(this.include == null || this.include.isEmpty())) {
             this.includes = parseIncludes(this.include);
         }
         if (this.includes != null) {
             subFilters.add(new PatternInclusionsFilter(includes));
         }
 
-        if (!StringUtils.isEmpty(this.exclude)) {
+        if (!(this.exclude == null || this.exclude.isEmpty())) {
             this.excludes = parseIncludes(this.exclude);
         }
         if (this.excludes != null) {
@@ -569,7 +569,7 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
                 .a(" with artifact ")
                 .strong(resolutionFuzziness)
                 .a(" resolution fuzziness")
-                .toString());
+                .build());
 
         for (Artifact artifact : artifacts) {
             verbose("Purging artifact: " + artifact.getId());
@@ -622,7 +622,7 @@ public class PurgeLocalRepositoryMojo extends AbstractMojo {
             }
         }
 
-        if (missingArtifacts.size() > 0) {
+        if (!missingArtifacts.isEmpty()) {
             StringBuilder message = new StringBuilder("required artifacts missing:");
             message.append(System.lineSeparator());
             for (Artifact missingArtifact : missingArtifacts) {
