@@ -28,22 +28,22 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.resolver.filter.ArtifactFilter;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
+import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.Parameter;
+import org.apache.maven.plugins.dependency.utils.StringUtils;
 import org.apache.maven.project.MavenProject;
 import org.apache.maven.shared.artifact.filter.StrictPatternExcludesArtifactFilter;
 import org.apache.maven.shared.dependency.analyzer.ProjectDependencyAnalysis;
 import org.apache.maven.shared.dependency.analyzer.ProjectDependencyAnalyzer;
 import org.apache.maven.shared.dependency.analyzer.ProjectDependencyAnalyzerException;
-import org.apache.maven.shared.utils.StringUtils;
-import org.codehaus.plexus.PlexusConstants;
 import org.codehaus.plexus.PlexusContainer;
-import org.codehaus.plexus.context.Context;
-import org.codehaus.plexus.personality.plexus.lifecycle.phase.Contextualizable;
+import org.codehaus.plexus.component.repository.exception.ComponentLookupException;
 import org.codehaus.plexus.util.xml.PrettyPrintXMLWriter;
 
 /**
@@ -53,19 +53,20 @@ import org.codehaus.plexus.util.xml.PrettyPrintXMLWriter;
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
  * @since 2.0-alpha-5
  */
-public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contextualizable {
+public abstract class AbstractAnalyzeMojo extends AbstractMojo {
     // fields -----------------------------------------------------------------
 
     /**
-     * The plexus context to look-up the right {@link ProjectDependencyAnalyzer} implementation depending on the mojo
+     * The plexusContainer to look-up the right {@link ProjectDependencyAnalyzer} implementation depending on the mojo
      * configuration.
      */
-    private Context context;
+    @Component
+    private PlexusContainer plexusContainer;
 
     /**
      * The Maven project to analyze.
      */
-    @Parameter(defaultValue = "${project}", readonly = true, required = true)
+    @Component
     private MavenProject project;
 
     /**
@@ -93,7 +94,7 @@ public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contex
 
     /**
      * Ignore Runtime/Provided/Test/System scopes for unused dependency analysis.
-     *
+     * <p>
      * <code><b>Non-test scoped</b></code> list will be not affected.
      */
     @Parameter(property = "ignoreNonCompile", defaultValue = "false")
@@ -260,10 +261,16 @@ public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contex
      *
      * @since 3.2.1
      */
-    // defaultValue value on @Parameter - not work with Maven 3.2.5
-    // When is set defaultValue always win, and there is no possibility to override by plugin configuration.
-    @Parameter
-    private List<String> ignoredPackagings = Arrays.asList("pom", "ear");
+    @Parameter(defaultValue = "pom,ear")
+    private List<String> ignoredPackagings;
+
+    /**
+     * List of class patterns excluded from analyze. Java regular expression pattern is applied to full class name.
+     *
+     * @since 3.7.0
+     */
+    @Parameter(property = "mdep.analyze.excludedClasses")
+    private Set<String> excludedClasses;
 
     // Mojo methods -----------------------------------------------------------
 
@@ -299,20 +306,15 @@ public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contex
      * @throws MojoExecutionException in case of an error.
      */
     protected ProjectDependencyAnalyzer createProjectDependencyAnalyzer() throws MojoExecutionException {
+
         try {
-            final PlexusContainer container = (PlexusContainer) context.get(PlexusConstants.PLEXUS_KEY);
-            return container.lookup(ProjectDependencyAnalyzer.class, analyzer);
-        } catch (Exception exception) {
+            return plexusContainer.lookup(ProjectDependencyAnalyzer.class, analyzer);
+        } catch (ComponentLookupException exception) {
             throw new MojoExecutionException(
                     "Failed to instantiate ProjectDependencyAnalyser" + " / role-hint " + analyzer, exception);
         }
     }
 
-    @Override
-    public void contextualize(Context theContext) {
-        this.context = theContext;
-    }
-
     /**
      * @return {@link #skip}
      */
@@ -325,7 +327,7 @@ public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contex
     private boolean checkDependencies() throws MojoExecutionException {
         ProjectDependencyAnalysis analysis;
         try {
-            analysis = createProjectDependencyAnalyzer().analyze(project);
+            analysis = createProjectDependencyAnalyzer().analyze(project, excludedClasses);
 
             if (usedDependencies != null) {
                 analysis = analysis.forceDeclaredDependenciesUsage(usedDependencies);
@@ -513,9 +515,9 @@ public abstract class AbstractAnalyzeMojo extends AbstractMojo implements Contex
                 writer.startElement("version");
                 writer.writeText(artifact.getBaseVersion());
                 String classifier = artifact.getClassifier();
-                if (StringUtils.isNotBlank(classifier)) {
+                if (!StringUtils.isEmpty(classifier)) {
                     writer.startElement("classifier");
-                    writer.writeText(artifact.getClassifier());
+                    writer.writeText(classifier);
                     writer.endElement();
                 }
                 writer.endElement();
