@@ -20,23 +20,25 @@ package org.apache.maven.plugins.dependency.analyze;
 
 import java.io.IOException;
 import java.io.Reader;
-import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
-import org.apache.commons.collections4.CollectionUtils;
+import java.util.stream.Collectors;
+
 import org.apache.maven.model.Dependency;
 import org.apache.maven.model.Model;
 import org.apache.maven.model.io.xpp3.MavenXpp3Reader;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
+import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.project.MavenProject;
-import org.codehaus.plexus.util.ReaderFactory;
+import org.codehaus.plexus.util.xml.XmlStreamReader;
 import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
 
 /**
@@ -64,7 +66,7 @@ public class AnalyzeDuplicateMojo extends AbstractMojo {
     /**
      * The Maven project to analyze.
      */
-    @Parameter(defaultValue = "${project}", readonly = true, required = true)
+    @Component
     private MavenProject project;
 
     /**
@@ -79,7 +81,7 @@ public class AnalyzeDuplicateMojo extends AbstractMojo {
 
         MavenXpp3Reader pomReader = new MavenXpp3Reader();
         Model model;
-        try (Reader reader = ReaderFactory.newXmlReader(project.getFile())) {
+        try (Reader reader = new XmlStreamReader(project.getFile())) {
             model = pomReader.read(reader);
         } catch (IOException | XmlPullParserException e) {
             throw new MojoExecutionException("Exception: " + e.getMessage(), e);
@@ -130,14 +132,11 @@ public class AnalyzeDuplicateMojo extends AbstractMojo {
     }
 
     private Set<String> findDuplicateDependencies(List<Dependency> modelDependencies) {
-        List<String> modelDependencies2 = new ArrayList<>();
-        for (Dependency dep : modelDependencies) {
-            modelDependencies2.add(dep.getManagementKey());
-        }
-
-        // @formatter:off
-        return new LinkedHashSet<>(
-                CollectionUtils.disjunction(modelDependencies2, new LinkedHashSet<>(modelDependencies2)));
-        // @formatter:on
+        List<String> modelDependencies2 =
+                modelDependencies.stream().map(Dependency::getManagementKey).collect(Collectors.toList());
+        // remove one instance of each element from the list
+        modelDependencies2.removeIf(new HashSet<>(modelDependencies2)::remove);
+        // keep a single instance of each duplicate
+        return new LinkedHashSet<>(modelDependencies2);
     }
 }
