@@ -22,6 +22,7 @@ import java.io.File;
 import java.util.Collections;
 import java.util.List;
 import java.util.Objects;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.handler.ArtifactHandler;
 import org.apache.maven.artifact.handler.manager.ArtifactHandlerManager;
@@ -32,6 +33,7 @@ import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojo;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
+import org.apache.maven.plugins.dependency.utils.StringUtils;
 import org.apache.maven.plugins.dependency.utils.filters.ArtifactItemFilter;
 import org.apache.maven.project.MavenProject;
 import org.apache.maven.project.ProjectBuildingRequest;
@@ -40,7 +42,6 @@ import org.apache.maven.shared.transfer.artifact.DefaultArtifactCoordinate;
 import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver;
 import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolverException;
 import org.apache.maven.shared.transfer.repository.RepositoryManager;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * Abstract parent class used by mojos that get Artifact information from the plugin configuration as an ArrayList of
@@ -78,8 +79,18 @@ public abstract class AbstractFromConfigurationMojo extends AbstractDependencyMo
      * Overwrite if newer
      *
      * @since 2.0
+     * @deprecated Use 'overWriteIfNewer' or 'mdep.overWriteIfNewer' as this does nothing now.
      */
+    @Deprecated
     @Parameter(property = "mdep.overIfNewer", defaultValue = "true")
+    private boolean overIfNewer;
+
+    /**
+     * Overwrite if newer
+     *
+     * @since 3.7.0
+     */
+    @Parameter(property = "mdep.overWriteIfNewer", defaultValue = "true")
     private boolean overWriteIfNewer;
 
     /**
@@ -134,13 +145,12 @@ public abstract class AbstractFromConfigurationMojo extends AbstractDependencyMo
     protected List<ArtifactItem> getProcessedArtifactItems(ProcessArtifactItemsRequest processArtifactItemsRequest)
             throws MojoExecutionException {
 
-        boolean removeVersion = processArtifactItemsRequest.isRemoveVersion(),
-                prependGroupId = processArtifactItemsRequest.isPrependGroupId(),
-                useBaseVersion = processArtifactItemsRequest.isUseBaseVersion();
-
+        boolean removeVersion = processArtifactItemsRequest.isRemoveVersion();
+        boolean prependGroupId = processArtifactItemsRequest.isPrependGroupId();
+        boolean useBaseVersion = processArtifactItemsRequest.isUseBaseVersion();
         boolean removeClassifier = processArtifactItemsRequest.isRemoveClassifier();
 
-        if (artifactItems == null || artifactItems.size() < 1) {
+        if (artifactItems == null || artifactItems.isEmpty()) {
             throw new MojoExecutionException("There are no artifactItems configured.");
         }
 
@@ -173,8 +183,8 @@ public abstract class AbstractFromConfigurationMojo extends AbstractDependencyMo
         return artifactItems;
     }
 
-    private boolean checkIfProcessingNeeded(ArtifactItem item) throws MojoExecutionException, ArtifactFilterException {
-        return StringUtils.equalsIgnoreCase(item.getOverWrite(), "true")
+    private boolean checkIfProcessingNeeded(ArtifactItem item) throws ArtifactFilterException {
+        return Boolean.parseBoolean(item.getOverWrite())
                 || getMarkedArtifactFilter(item).isArtifactIncluded(item);
     }
 
@@ -182,24 +192,14 @@ public abstract class AbstractFromConfigurationMojo extends AbstractDependencyMo
      * Resolves the Artifact from the remote repository if necessary. If no version is specified, it will be retrieved
      * from the dependency list or from the DependencyManagement section of the pom.
      *
-     * @param artifactItem containing information about artifact from plugin configuration.
-     * @return Artifact object representing the specified file.
-     * @throws MojoExecutionException with a message if the version can't be found in DependencyManagement.
+     * @param artifactItem containing information about artifact from plugin configuration
+     * @return Artifact object representing the specified file
+     * @throws MojoExecutionException if the version can't be found in DependencyManagement
      */
     protected Artifact getArtifact(ArtifactItem artifactItem) throws MojoExecutionException {
         Artifact artifact;
 
         try {
-            // mdep-50 - rolledback for now because it's breaking some functionality.
-            /*
-             * List listeners = new ArrayList(); Set theSet = new HashSet(); theSet.add( artifact );
-             * ArtifactResolutionResult artifactResolutionResult = artifactCollector.collect( theSet, project
-             * .getArtifact(), managedVersions, this.local, project.getRemoteArtifactRepositories(),
-             * artifactMetadataSource, null, listeners ); Iterator iter =
-             * artifactResolutionResult.getArtifactResolutionNodes().iterator(); while ( iter.hasNext() ) {
-             * ResolutionNode node = (ResolutionNode) iter.next(); artifact = node.getArtifact(); }
-             */
-
             ProjectBuildingRequest buildingRequest = newResolveArtifactProjectBuildingRequest();
 
             if (localRepositoryDirectory != null) {
@@ -366,7 +366,7 @@ public abstract class AbstractFromConfigurationMojo extends AbstractDependencyMo
         if (artifact != null) {
             String packaging = "jar";
             String classifier;
-            String[] tokens = StringUtils.split(artifact, ":");
+            String[] tokens = artifact.split(":");
             if (tokens.length < 3 || tokens.length > 5) {
                 throw new MojoFailureException("Invalid artifact, "
                         + "you must specify groupId:artifactId:version[:packaging[:classifier]] " + artifact);
