@@ -20,8 +20,10 @@ package org.apache.maven.plugins.dependency.fromConfiguration;
 
 import java.io.File;
 import java.util.Objects;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.ArtifactUtils;
+import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
 import org.apache.maven.shared.transfer.dependencies.DependableCoordinate;
 import org.codehaus.plexus.components.io.filemappers.FileMapper;
@@ -36,53 +38,45 @@ public class ArtifactItem implements DependableCoordinate {
     /**
      * Group Id of Artifact
      *
-     * @parameter
-     * @required
      */
+    @Parameter(required = true)
     private String groupId;
 
     /**
      * Name of Artifact
-     *
-     * @parameter
-     * @required
      */
+    @Parameter(required = true)
     private String artifactId;
 
     /**
      * Version of Artifact
-     *
-     * @parameter
      */
+    @Parameter
     private String version = null;
 
     /**
      * Type of Artifact (War,Jar,etc)
      *
-     * @parameter
-     * @required
      */
+    @Parameter(required = true)
     private String type = "jar";
 
     /**
      * Classifier for Artifact (tests,sources,etc)
-     *
-     * @parameter
      */
+    @Parameter
     private String classifier;
 
     /**
      * Location to use for this Artifact. Overrides default location.
-     *
-     * @parameter
      */
+    @Parameter
     private File outputDirectory;
 
     /**
      * Provides ability to change destination file name
-     *
-     * @parameter
      */
+    @Parameter
     private String destFileName;
 
     /**
@@ -92,9 +86,8 @@ public class ArtifactItem implements DependableCoordinate {
 
     /**
      * Encoding of artifact. Overrides default encoding.
-     *
-     * @parameter
      */
+    @Parameter
     private String encoding;
 
     /**
@@ -121,9 +114,8 @@ public class ArtifactItem implements DependableCoordinate {
      * {@link FileMapper}s to be used for rewriting each target path, or {@code null} if no rewriting shall happen.
      *
      * @since 3.1.2
-     *
-     * @parameter
      */
+    @Parameter
     private FileMapper[] fileMappers;
 
     /**
