@@ -19,12 +19,17 @@
 package org.apache.maven.plugins.dependency.fromConfiguration;
 
 import java.io.File;
+import java.io.IOException;
 import java.util.List;
+
+import org.apache.maven.artifact.Artifact;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
+import org.apache.maven.plugins.annotations.Component;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
 import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
+import org.apache.maven.plugins.dependency.utils.CopyUtil;
 import org.apache.maven.plugins.dependency.utils.filters.ArtifactItemFilter;
 import org.apache.maven.plugins.dependency.utils.filters.DestFileFilter;
 
@@ -37,6 +42,8 @@ import org.apache.maven.plugins.dependency.utils.filters.DestFileFilter;
 @Mojo(name = "copy", defaultPhase = LifecyclePhase.PROCESS_SOURCES, requiresProject = false, threadSafe = true)
 public class CopyMojo extends AbstractFromConfigurationMojo {
 
+    @Component
+    private CopyUtil copyUtil;
     /**
      * Strip artifact version during copy
      */
@@ -73,18 +80,6 @@ public class CopyMojo extends AbstractFromConfigurationMojo {
     @Parameter(property = "artifact")
     private String artifact;
 
-    /**
-     * <i>not used in this goal</i>
-     */
-    @Parameter
-    protected boolean useJvmChmod = true;
-
-    /**
-     * <i>not used in this goal</i>
-     */
-    @Parameter
-    protected boolean ignorePermissions;
-
     /**
      * Main entry into mojo. This method gets the ArtifactItems and iterates through each one passing it to
      * copyArtifact.
@@ -114,12 +109,19 @@ public class CopyMojo extends AbstractFromConfigurationMojo {
      *
      * @param artifactItem containing the information about the Artifact to copy.
      * @throws MojoExecutionException with a message if an error occurs.
-     * @see #copyFile(File, File)
+     * @see CopyUtil#copyArtifactFile(Artifact, File)
      */
     protected void copyArtifact(ArtifactItem artifactItem) throws MojoExecutionException {
         File destFile = new File(artifactItem.getOutputDirectory(), artifactItem.getDestFileName());
 
-        copyFile(artifactItem.getArtifact().getFile(), destFile);
+        try {
+            copyUtil.copyArtifactFile(artifactItem.getArtifact(), destFile);
+        } catch (IOException e) {
+            throw new MojoExecutionException(
+                    "Failed to copy artifact '" + artifactItem.getArtifact() + "' ("
+                            + artifactItem.getArtifact().getFile() + ") to " + destFile,
+                    e);
+        }
     }
 
     @Override
