@@ -18,15 +18,12 @@
  */
 package org.apache.maven.plugins.dependency.fromDependencies;
 
-import java.io.BufferedReader;
-import java.io.BufferedWriter;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
 import java.io.IOException;
-import java.io.InputStreamReader;
-import java.io.OutputStreamWriter;
 import java.io.Writer;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.Comparator;
 import java.util.Iterator;
@@ -35,6 +32,9 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.annotations.Component;
@@ -47,7 +47,6 @@ import org.apache.maven.project.MavenProjectHelper;
 import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactsFilter;
 import org.apache.maven.shared.transfer.repository.RepositoryManager;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * This goal outputs a classpath string of dependencies from the local repository to a file or log.
@@ -87,7 +86,7 @@ public class BuildClasspathMojo extends AbstractDependencyFilterMojo implements
     private String prefix;
 
     /**
-     * A property to set to the content of the classpath string.
+     * If defined, the name of a property to which the classpath string will be written.
      */
     @Parameter(property = "mdep.outputProperty")
     private String outputProperty;
@@ -177,11 +176,11 @@ public class BuildClasspathMojo extends AbstractDependencyFilterMojo implements
     @Override
     protected void doExecute() throws MojoExecutionException {
         // initialize the separators.
-        boolean isFileSepSet = StringUtils.isNotEmpty(fileSeparator);
-        boolean isPathSepSet = StringUtils.isNotEmpty(pathSeparator);
+        boolean isFileSepSet = fileSeparator != null && !fileSeparator.isEmpty();
+        boolean isPathSepSet = pathSeparator != null && !pathSeparator.isEmpty();
 
         // don't allow them to have absolute paths when they attach.
-        if (attach && StringUtils.isEmpty(localRepoProperty)) {
+        if (attach && (localRepoProperty == null || localRepoProperty.isEmpty())) {
             localRepoProperty = "${M2_REPO}";
         }
 
@@ -263,11 +262,11 @@ public class BuildClasspathMojo extends AbstractDependencyFilterMojo implements
         if (prefix == null) {
             String file = art.getFile().getPath();
             // substitute the property for the local repo path to make the classpath file portable.
-            if (StringUtils.isNotEmpty(localRepoProperty)) {
+            if (localRepoProperty != null && !localRepoProperty.isEmpty()) {
                 ProjectBuildingRequest projectBuildingRequest = session.getProjectBuildingRequest();
                 File localBasedir = repositoryManager.getLocalRepositoryBasedir(projectBuildingRequest);
 
-                file = StringUtils.replace(file, localBasedir.getAbsolutePath(), localRepoProperty);
+                file = file.replace(localBasedir.getAbsolutePath(), localRepoProperty);
             }
             sb.append(file);
         } else {
@@ -306,9 +305,8 @@ public class BuildClasspathMojo extends AbstractDependencyFilterMojo implements
         // make sure the parent path exists.
         out.getParentFile().mkdirs();
 
-        String encoding = Objects.toString(outputEncoding, "UTF-8");
-
-        try (Writer w = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(out), encoding))) {
+        String encoding = Objects.toString(outputEncoding, StandardCharsets.UTF_8.name());
+        try (Writer w = Files.newBufferedWriter(out.toPath(), Charset.forName(encoding))) {
             w.write(cpString);
             getLog().info("Wrote classpath file '" + out + "'.");
         } catch (IOException ex) {
@@ -332,15 +330,11 @@ public class BuildClasspathMojo extends AbstractDependencyFilterMojo implements
         if (!outputFile.isFile()) {
             return null;
         }
-        StringBuilder sb = new StringBuilder();
-        String encoding = Objects.toString(outputEncoding, "UTF-8");
 
-        try (BufferedReader r = new BufferedReader(new InputStreamReader(new FileInputStream(outputFile), encoding))) {
-            for (String line = r.readLine(); line != null; line = r.readLine()) {
-                sb.append(line);
-            }
+        String encoding = Objects.toString(outputEncoding, StandardCharsets.UTF_8.name());
 
-            return sb.toString();
+        try (Stream<String> lines = Files.lines(outputFile.toPath(), Charset.forName(encoding))) {
+            return lines.collect(Collectors.joining());
         }
     }
 
