@@ -19,9 +19,12 @@
 package org.apache.maven.plugins.dependency.resolvers;
 
 import java.io.IOException;
+import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.Objects;
 import java.util.Set;
+
+import org.apache.maven.RepositoryUtils;
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
@@ -30,11 +33,19 @@ import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
 import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactFilterException;
+import org.apache.maven.shared.artifact.filter.collection.ArtifactIdFilter;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactsFilter;
+import org.apache.maven.shared.artifact.filter.collection.ClassifierFilter;
 import org.apache.maven.shared.artifact.filter.collection.FilterArtifacts;
+import org.apache.maven.shared.artifact.filter.collection.GroupIdFilter;
+import org.apache.maven.shared.artifact.filter.collection.ScopeFilter;
+import org.apache.maven.shared.artifact.filter.collection.TypeFilter;
 import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolverException;
+import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResult;
 import org.apache.maven.shared.transfer.dependencies.DefaultDependableCoordinate;
+import org.apache.maven.shared.transfer.dependencies.DependableCoordinate;
 import org.apache.maven.shared.transfer.dependencies.resolve.DependencyResolverException;
+import org.eclipse.aether.resolution.ArtifactResolutionException;
 
 /**
  * Goal that resolves all project plugins and reports and their dependencies.
@@ -48,6 +59,14 @@ public class ResolvePluginsMojo extends AbstractResolveMojo {
     @Parameter(property = "outputEncoding", defaultValue = "${project.reporting.outputEncoding}")
     private String outputEncoding;
 
+    /**
+     * Output absolute filename for resolved artifacts
+     *
+     * @since 2.0
+     */
+    @Parameter(property = "outputAbsoluteArtifactFilename", defaultValue = "false")
+    private boolean outputAbsoluteArtifactFilename;
+
     /**
      * Main entry into mojo. Gets the list of dependencies and iterates through displaying the resolved version.
      *
@@ -123,11 +142,72 @@ public class ResolvePluginsMojo extends AbstractResolveMojo {
                     DependencyUtil.write(output, outputFile, appendOutput, encoding);
                 }
             }
-        } catch (IOException | ArtifactFilterException | ArtifactResolverException | DependencyResolverException e) {
+        } catch (IOException
+                | ArtifactFilterException
+                | ArtifactResolverException
+                | DependencyResolverException
+                | ArtifactResolutionException e) {
             throw new MojoExecutionException(e.getMessage(), e);
         }
     }
 
+    /**
+     * This method resolves all transitive dependencies of an artifact.
+     *
+     * @param artifact the artifact used to retrieve dependencies
+     * @return resolved set of dependencies
+     * @throws DependencyResolverException in case of error while resolving artifacts.
+     */
+    private Set<Artifact> resolveArtifactDependencies(final DependableCoordinate artifact)
+            throws DependencyResolverException {
+        ProjectBuildingRequest buildingRequest = newResolveArtifactProjectBuildingRequest();
+
+        Iterable<ArtifactResult> artifactResults =
+                getDependencyResolver().resolveDependencies(buildingRequest, artifact, null);
+
+        Set<Artifact> artifacts = new LinkedHashSet<>();
+
+        for (final ArtifactResult artifactResult : artifactResults) {
+            artifacts.add(artifactResult.getArtifact());
+        }
+
+        return artifacts;
+    }
+
+    /**
+     * @return {@link FilterArtifacts}
+     */
+    private FilterArtifacts getArtifactsFilter() {
+        final FilterArtifacts filter = new FilterArtifacts();
+
+        if (excludeReactor) {
+
+            filter.addFilter(new ExcludeReactorProjectsArtifactFilter(reactorProjects, getLog()));
+        }
+
+        filter.addFilter(new ScopeFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeScope),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeScope)));
+
+        filter.addFilter(new TypeFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeTypes),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeTypes)));
+
+        filter.addFilter(new ClassifierFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeClassifiers),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeClassifiers)));
+
+        filter.addFilter(new GroupIdFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeGroupIds),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeGroupIds)));
+
+        filter.addFilter(new ArtifactIdFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeArtifactIds),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeArtifactIds)));
+
+        return filter;
+    }
+
     /**
      * This method resolves the plugin artifacts from the project.
      *
@@ -135,42 +215,27 @@ public class ResolvePluginsMojo extends AbstractResolveMojo {
      * @throws ArtifactFilterException in case of an error
      * @throws ArtifactResolverException in case of an error
      */
-    protected Set<Artifact> resolvePluginArtifacts() throws ArtifactFilterException, ArtifactResolverException {
+    private Set<Artifact> resolvePluginArtifacts()
+            throws ArtifactFilterException, ArtifactResolverException, ArtifactResolutionException {
         final Set<Artifact> plugins = getProject().getPluginArtifacts();
         final Set<Artifact> reports = getProject().getReportArtifacts();
 
-        Set<Artifact> artifacts = new LinkedHashSet<>();
+        Set<Artifact> artifacts = new HashSet<>();
         artifacts.addAll(reports);
         artifacts.addAll(plugins);
 
         final FilterArtifacts filter = getArtifactsFilter();
         artifacts = filter.filter(artifacts);
 
-        Set<Artifact> resolvedArtifacts = new LinkedHashSet<>(artifacts.size());
-        // final ArtifactFilter filter = getPluginFilter();
+        Set<Artifact> result = new HashSet<>();
         for (final Artifact artifact : new LinkedHashSet<>(artifacts)) {
-            // if ( !filter.include( artifact ) )
-            // {
-            // final String logStr =
-            // String.format( " Plugin SKIPPED: %s", DependencyUtil.getFormattedFileName( artifact, false ) );
-            //
-            // if ( !silent )
-            // {
-            // this.getLog().info( logStr );
-            // }
-            //
-            // artifacts.remove( artifact );
-            // continue;
-            // }
 
-            ProjectBuildingRequest buildingRequest = newResolvePluginProjectBuildingRequest();
-
-            // resolve the new artifact
-            resolvedArtifacts.add(getArtifactResolver()
-                    .resolveArtifact(buildingRequest, artifact)
-                    .getArtifact());
+            org.eclipse.aether.artifact.Artifact resolveArtifact = getResolverUtil()
+                    .resolveArtifact(
+                            RepositoryUtils.toArtifact(artifact), getProject().getRemotePluginRepositories());
+            result.add(RepositoryUtils.toArtifact(resolveArtifact));
         }
-        return artifacts;
+        return result;
     }
 
     @Override
