@@ -23,12 +23,14 @@ import java.io.IOException;
 import java.nio.file.Files;
 import java.util.LinkedHashSet;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.plugins.dependency.fromConfiguration.ArtifactItem;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
 import org.apache.maven.shared.artifact.filter.collection.AbstractArtifactsFilter;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactFilterException;
-import org.codehaus.plexus.util.StringUtils;
+
+import static org.apache.maven.plugins.dependency.utils.StringUtils.isEmpty;
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
@@ -283,7 +285,8 @@ public class DestFileFilter extends AbstractArtifactsFilter implements ArtifactI
         }
 
         File destFile;
-        if (StringUtils.isEmpty(item.getDestFileName())) {
+
+        if (isEmpty(item.getDestFileName())) {
             String formattedFileName = DependencyUtil.getFormattedFileName(
                     artifact, removeVersion, prependGroupId, useBaseVersion, removeClassifier);
             destFile = new File(destFolder, formattedFileName);
@@ -298,7 +301,7 @@ public class DestFileFilter extends AbstractArtifactsFilter implements ArtifactI
 
     /**
      * Using simply {@code File.getLastModified} will return sometimes a wrong value see JDK bug for details.
-     *
+     * <p>
      * https://bugs.openjdk.java.net/browse/JDK-8177809
      *
      * @param file {@link File}
