@@ -19,8 +19,9 @@
 package org.apache.maven.plugins.dependency.utils.markers;
 
 import java.io.File;
+
 import org.apache.maven.plugins.dependency.fromConfiguration.ArtifactItem;
-import org.codehaus.plexus.util.StringUtils;
+import org.apache.maven.plugins.dependency.utils.StringUtils;
 
 /**
  * @author <a href="mailto:dbradicich@comcast.net">Damian Bradicich</a>
@@ -49,7 +50,7 @@ public class UnpackFileMarkerHandler extends DefaultFileMarkerHandler {
 
     @Override
     protected File getMarkerFile() {
-        /**
+        /*
          * Build a hash of all include/exclude strings, to determine if an artifactItem has been unpacked using the
          * include/exclude parameters, this will allow an artifact to be included multiple times with different
          * include/exclude parameters
