@@ -20,9 +20,12 @@ package org.apache.maven.plugins.dependency;
 
 import java.io.File;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
+import org.apache.maven.execution.MavenSession;
 import org.apache.maven.plugin.testing.SilentLog;
 import org.apache.maven.plugins.dependency.resolvers.CollectDependenciesMojo;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.DependencyStatusSets;
 import org.apache.maven.project.MavenProject;
 
@@ -31,6 +34,11 @@ public class TestCollectMojo extends AbstractDependencyMojoTestCase {
     protected void setUp() throws Exception {
         // required for mojo lookups to work
         super.setUp("markers", false);
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
     }
 
     /**
