@@ -23,6 +23,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.versioning.VersionRange;
 import org.apache.maven.execution.MavenSession;
@@ -30,6 +31,7 @@ import org.apache.maven.model.Dependency;
 import org.apache.maven.plugin.LegacySupport;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
 import org.apache.maven.project.MavenProject;
 
@@ -38,6 +40,11 @@ public class TestCopyMojo extends AbstractDependencyMojoTestCase {
 
     protected void setUp() throws Exception {
         super.setUp("copy", false, false);
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
 
         File testPom = new File(getBasedir(), "target/test-classes/unit/copy-test/plugin-config.xml");
         mojo = (CopyMojo) lookupMojo("copy", testPom);
@@ -47,9 +54,6 @@ public class TestCopyMojo extends AbstractDependencyMojoTestCase {
         assertNotNull(mojo);
         assertNotNull(mojo.getProject());
 
-        MavenSession session = newMavenSession(mojo.getProject());
-        setVariableValueToObject(mojo, "session", session);
-
         LegacySupport legacySupport = lookup(LegacySupport.class);
         legacySupport.setSession(session);
         installLocalRepository(legacySupport);
