@@ -22,13 +22,15 @@ import java.io.File;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.execution.MavenSession;
 import org.apache.maven.plugin.LegacySupport;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.markers.UnpackFileMarkerHandler;
-import org.codehaus.plexus.archiver.manager.ArchiverManager;
+import org.apache.maven.project.MavenProject;
 
 public class TestIncludeExcludeUnpackMojo extends AbstractDependencyMojoTestCase {
     private final String PACKED_FILE = "test.zip";
@@ -45,13 +47,17 @@ public class TestIncludeExcludeUnpackMojo extends AbstractDependencyMojoTestCase
         // required for mojo lookups to work
         super.setUp("unpack", true, false);
 
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
+
         File testPom = new File(getBasedir(), "target/test-classes/unit/unpack-test/plugin-config.xml");
         mojo = (UnpackMojo) lookupMojo("unpack", testPom);
         mojo.setOutputDirectory(new File(this.testDir, "outputDirectory"));
         // mojo.silent = true;
 
-        // it needs to get the archivermanager
-        // stubFactory.setUnpackableFile( mojo.getArchiverManager() );
         // i'm using one file repeatedly to archive so I can test the name
         // programmatically.
         stubFactory.setSrcFile(new File(getBasedir() + File.separatorChar + PACKED_FILE_PATH));
@@ -62,14 +68,9 @@ public class TestIncludeExcludeUnpackMojo extends AbstractDependencyMojoTestCase
         assertNotNull(mojo);
         assertNotNull(mojo.getProject());
 
-        mojo.setArchiverManager(lookup(ArchiverManager.class));
-
         mojo.setMarkersDirectory(new File(this.testDir, "markers"));
         mojo.setArtifactItems(list);
 
-        MavenSession session = newMavenSession(mojo.getProject());
-        setVariableValueToObject(mojo, "session", session);
-
         LegacySupport legacySupport = lookup(LegacySupport.class);
         legacySupport.setSession(session);
         installLocalRepository(legacySupport);
