@@ -25,6 +25,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.versioning.VersionRange;
 import org.apache.maven.execution.MavenSession;
@@ -33,8 +34,12 @@ import org.apache.maven.plugin.LegacySupport;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
 import org.apache.maven.plugins.dependency.testUtils.DependencyArtifactStubFactory;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.markers.UnpackFileMarkerHandler;
 import org.apache.maven.project.MavenProject;
+import org.codehaus.plexus.archiver.manager.ArchiverManager;
+
+import static org.junit.Assert.assertNotEquals;
 
 public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
 
@@ -43,6 +48,12 @@ public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
     protected void setUp() throws Exception {
         super.setUp("unpack", true, false);
 
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
+
         File testPom = new File(getBasedir(), "target/test-classes/unit/unpack-test/plugin-config.xml");
         mojo = (UnpackMojo) lookupMojo("unpack", testPom);
         mojo.setOutputDirectory(new File(this.testDir, "outputDirectory"));
@@ -54,17 +65,12 @@ public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
         // MavenProject project = mojo.getProject();
         // init classifier things
         // it needs to get the archivermanager
-        stubFactory.setUnpackableFile(mojo.getArchiverManager());
+        stubFactory.setUnpackableFile(lookup(ArchiverManager.class));
         // i'm using one file repeatedly to archive so I can test the name
         // programmatically.
         stubFactory.setSrcFile(new File(
                 getBasedir() + File.separatorChar + "target/test-classes/unit/unpack-dependencies-test/test.txt"));
 
-        mojo.setUseJvmChmod(true);
-
-        MavenSession session = newMavenSession(mojo.getProject());
-        setVariableValueToObject(mojo, "session", session);
-
         LegacySupport legacySupport = lookup(LegacySupport.class);
 
         legacySupport.setSession(session);
@@ -487,13 +493,13 @@ public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
         // round down to the last second
         long time = now;
         time = time - (time % 1000);
-        // go back 10 more seconds for linux
-        time -= 10000;
+        // go back 30 more seconds for linux
+        time -= 30000;
         // set to known value
         assertTrue(unpackedFile.setLastModified(time));
         // set source to be newer about some seconds,
-        // especially on macOS it shouldn't be smaller than 8s in order to mitigate flapping test
-        assertTrue(artifact.getFile().setLastModified(time + 8000));
+        // especially on macOS it shouldn't be smaller than 16s in order to mitigate flapping test
+        assertTrue(artifact.getFile().setLastModified(time + 16000));
 
         // manually set markerfile (must match getMarkerFile in DefaultMarkerFileHandler)
         File marker = new File(mojo.getMarkersDirectory(), artifact.getId().replace(':', '-') + ".marker");
@@ -506,10 +512,11 @@ public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
         long unpackedFileLastModifiedMillis =
                 Files.getLastModifiedTime(unpackedFile.toPath()).toMillis();
 
-        assertTrue(
+        assertNotEquals(
                 "unpackedFile '" + unpackedFile + "' lastModified() == " + markerLastModifiedMillis
                         + ": should be different",
-                markerLastModifiedMillis != unpackedFileLastModifiedMillis);
+                markerLastModifiedMillis,
+                unpackedFileLastModifiedMillis);
     }
 
     public void assertUnpacked(ArtifactItem item, boolean overWrite) throws Exception {
@@ -526,7 +533,7 @@ public class TestUnpackMojo extends AbstractDependencyMojoTestCase {
         mojo.execute();
 
         if (overWrite) {
-            assertTrue(time != unpackedFile.lastModified());
+            assertNotEquals(time, unpackedFile.lastModified());
         } else {
             assertEquals(time, unpackedFile.lastModified());
         }
