@@ -20,10 +20,12 @@ package org.apache.maven.plugins.dependency.fromDependencies;
 
 import java.io.File;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.execution.MavenSession;
 import org.apache.maven.plugin.LegacySupport;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
 import org.apache.maven.project.MavenProject;
 
@@ -35,6 +37,12 @@ public class TestBuildClasspathMojo extends AbstractDependencyMojoTestCase {
         // required for mojo lookups to work
         super.setUp("build-classpath", true);
 
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
+
         File testPom = new File(getBasedir(), "target/test-classes/unit/build-classpath-test/plugin-config.xml");
         mojo = (BuildClasspathMojo) lookupMojo("build-classpath", testPom);
 
@@ -70,7 +78,7 @@ public class TestBuildClasspathMojo extends AbstractDependencyMojoTestCase {
 
         String file = mojo.readClasspathFile();
         assertNotNull(file);
-        assertTrue(file.length() > 0);
+        assertFalse(file.isEmpty());
 
         assertTrue(file.contains(File.pathSeparator));
         assertTrue(file.contains(File.separator));
@@ -84,7 +92,7 @@ public class TestBuildClasspathMojo extends AbstractDependencyMojoTestCase {
 
         file = mojo.readClasspathFile();
         assertNotNull(file);
-        assertTrue(file.length() > 0);
+        assertFalse(file.isEmpty());
 
         assertFalse(file.contains(File.pathSeparator));
         assertFalse(file.contains(File.separator));
@@ -100,11 +108,9 @@ public class TestBuildClasspathMojo extends AbstractDependencyMojoTestCase {
     }
 
     public void testPath() throws Exception {
-        MavenSession session = newMavenSession(mojo.getProject());
-        setVariableValueToObject(mojo, "session", session);
 
         LegacySupport legacySupport = lookup(LegacySupport.class);
-        legacySupport.setSession(session);
+        legacySupport.setSession(lookup(MavenSession.class));
         installLocalRepository(legacySupport);
 
         Artifact artifact = stubFactory.getReleaseArtifact();
