@@ -22,6 +22,7 @@ import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.handler.manager.ArtifactHandlerManager;
 import org.apache.maven.artifact.resolver.filter.ScopeArtifactFilter;
@@ -29,11 +30,14 @@ import org.apache.maven.execution.MavenSession;
 import org.apache.maven.plugin.LegacySupport;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugin.MojoFailureException;
+import org.apache.maven.plugin.testing.stubs.ArtifactStub;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
+import org.apache.maven.plugins.dependency.testUtils.stubs.DependencyProjectStub;
 import org.apache.maven.plugins.dependency.utils.DependencyUtil;
+import org.apache.maven.plugins.dependency.utils.ResolverUtil;
 import org.apache.maven.plugins.dependency.utils.markers.DefaultFileMarkerHandler;
 import org.apache.maven.project.MavenProject;
-import org.codehaus.plexus.util.StringUtils;
+import org.eclipse.aether.RepositorySystem;
 
 public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
@@ -44,6 +48,16 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
         // required for mojo lookups to work
         super.setUp("copy-dependencies", true, false);
 
+        MavenProject project = new DependencyProjectStub();
+        getContainer().addComponent(project, MavenProject.class.getName());
+
+        MavenSession session = newMavenSession(project);
+        getContainer().addComponent(session, MavenSession.class.getName());
+
+        RepositorySystem repositorySystem = lookup(RepositorySystem.class);
+        ResolverUtil resolverUtil = new ResolverUtil(repositorySystem, () -> session);
+        getContainer().addComponent(resolverUtil, ResolverUtil.class.getName());
+
         File testPom = new File(getBasedir(), "target/test-classes/unit/copy-dependencies-test/plugin-config.xml");
         mojo = (CopyDependenciesMojo) lookupMojo("copy-dependencies", testPom);
         mojo.outputDirectory = new File(this.testDir, "outputDirectory");
@@ -51,10 +65,6 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
         assertNotNull(mojo);
         assertNotNull(mojo.getProject());
-        MavenProject project = mojo.getProject();
-
-        MavenSession session = newMavenSession(project);
-        setVariableValueToObject(mojo, "session", session);
 
         LegacySupport legacySupport = lookup(LegacySupport.class);
         legacySupport.setSession(session);
@@ -77,14 +87,19 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
         assertFalse(handle.isMarkerSet());
     }
 
-    public void testCopyFile() throws MojoExecutionException, IOException {
+    public void testCopyArtifactFile() throws Exception {
+        final Artifact srcArtifact = new ArtifactStub();
+        srcArtifact.setGroupId("org.apache.maven.plugins");
+        srcArtifact.setArtifactId("maven-dependency-plugin-dummy");
+        srcArtifact.setVersion("1.0");
         File src = File.createTempFile("copy", null);
+        srcArtifact.setFile(src);
 
         File dest = new File(mojo.outputDirectory, "toMe.jar");
 
         assertFalse(dest.exists());
 
-        copyFile(mojo, src, dest);
+        copyArtifactFile(srcArtifact, dest);
         assertTrue(dest.exists());
     }
 
@@ -156,7 +171,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeType() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getTypedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeTypes = "jar";
         mojo.execute();
 
@@ -170,7 +185,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testIncludeType() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getTypedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
 
         mojo.includeTypes = "jar";
         mojo.excludeTypes = "jar";
@@ -198,7 +213,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeArtifactId() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getArtifactArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeArtifactIds = "one";
         mojo.execute();
 
@@ -212,7 +227,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testIncludeArtifactId() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getArtifactArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
 
         mojo.includeArtifactIds = "one";
         mojo.excludeArtifactIds = "one";
@@ -240,7 +255,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testIncludeGroupId() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getGroupIdArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.includeGroupIds = "one";
         mojo.excludeGroupIds = "one";
         // shouldn't get anything
@@ -267,7 +282,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeGroupId() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getGroupIdArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeGroupIds = "one";
         mojo.execute();
 
@@ -282,7 +297,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeMultipleGroupIds() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getGroupIdArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeGroupIds = "one,two";
         mojo.execute();
 
@@ -298,7 +313,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeClassifier() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getClassifiedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeClassifiers = "one";
         mojo.execute();
 
@@ -312,7 +327,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testIncludeClassifier() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getClassifiedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
 
         mojo.includeClassifiers = "one";
         mojo.excludeClassifiers = "one";
@@ -340,7 +355,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testSubPerType() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getTypedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.useSubDirectoryPerType = true;
         mojo.execute();
 
@@ -389,10 +404,10 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
             String useClassifier = artifact.getClassifier();
             String useType = artifact.getType();
 
-            if (StringUtils.isNotEmpty(testClassifier)) {
+            if (testClassifier != null && !testClassifier.isEmpty()) {
                 useClassifier = "-" + testClassifier;
                 // type is only used if classifier is used.
-                if (StringUtils.isNotEmpty(testType)) {
+                if (testType != null && !testType.isEmpty()) {
                     useType = testType;
                 }
             }
@@ -414,6 +429,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void dotestArtifactExceptions() throws MojoFailureException {
         mojo.classifier = "jdk";
+        mojo.failOnMissingClassifierArtifact = true;
         mojo.type = "java-sources";
 
         try {
@@ -555,7 +571,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeProvidedScope() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getScopedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeScope = "provided";
         // mojo.silent = false;
 
@@ -573,7 +589,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeSystemScope() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getScopedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeScope = "system";
         // mojo.silent = false;
 
@@ -591,7 +607,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeCompileScope() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getScopedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeScope = "compile";
         mojo.execute();
         ScopeArtifactFilter saf = new ScopeArtifactFilter(mojo.excludeScope);
@@ -607,7 +623,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeTestScope() throws IOException, MojoFailureException {
         mojo.getProject().setArtifacts(stubFactory.getScopedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeScope = "test";
 
         try {
@@ -620,7 +636,7 @@ public class TestCopyDependenciesMojo extends AbstractDependencyMojoTestCase {
 
     public void testExcludeRuntimeScope() throws Exception {
         mojo.getProject().setArtifacts(stubFactory.getScopedArtifacts());
-        mojo.getProject().setDependencyArtifacts(new HashSet<Artifact>());
+        mojo.getProject().setDependencyArtifacts(new HashSet<>());
         mojo.excludeScope = "runtime";
         mojo.execute();
         ScopeArtifactFilter saf = new ScopeArtifactFilter(mojo.excludeScope);
