@@ -22,6 +22,7 @@ import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.Set;
+
 import junit.framework.TestCase;
 import org.apache.commons.io.FileUtils;
 import org.apache.maven.artifact.Artifact;
@@ -59,8 +60,8 @@ public class TestDestFileFilter extends TestCase {
         FileUtils.deleteDirectory(outputFolder);
     }
 
-    public File createFile(Artifact artifact) throws IOException {
-        return createFile(artifact, false, false, false);
+    public void createFile(Artifact artifact) throws IOException {
+        createFile(artifact, false, false, false);
     }
 
     public File createFile(
