@@ -22,6 +22,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
+
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.factory.ArtifactFactory;
 import org.apache.maven.artifact.factory.DefaultArtifactFactory;
@@ -36,7 +37,6 @@ import org.apache.maven.plugin.testing.stubs.MavenProjectStub;
 import org.apache.maven.plugin.testing.stubs.StubArtifactRepository;
 import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
 import org.apache.maven.plugins.dependency.testUtils.DependencyArtifactStubFactory;
-import org.apache.maven.shared.transfer.artifact.ArtifactCoordinate;
 
 /**
  * @author brianf
@@ -86,18 +86,18 @@ public class TestClassifierTypeTranslator extends AbstractDependencyMojoTestCase
         String type = "zip";
 
         ArtifactTranslator at = new ClassifierTypeTranslator(artifactHandlerManager, classifier, type);
-        Set<ArtifactCoordinate> results = at.translate(artifacts, log);
+        Set<org.eclipse.aether.artifact.Artifact> results = at.translate(artifacts, log);
 
         for (Artifact artifact : artifacts) {
-            Iterator<ArtifactCoordinate> resultIter = results.iterator();
+            Iterator<org.eclipse.aether.artifact.Artifact> resultIter = results.iterator();
             boolean found = false;
             while (resultIter.hasNext()) {
-                ArtifactCoordinate translatedArtifact = resultIter.next();
+                org.eclipse.aether.artifact.Artifact translatedArtifact = resultIter.next();
                 if (artifact.getArtifactId().equals(translatedArtifact.getArtifactId())
                         && artifact.getGroupId().equals(translatedArtifact.getGroupId())
                 /* && artifact.getScope().equals(translatedArtifact.getScope()) */ ) {
-                    // classifier is null, should be the same as the artifact
-                    assertEquals(artifact.getClassifier(), translatedArtifact.getClassifier());
+                    // classifier is always empty for Resolver sub artifact
+                    assertEquals("", translatedArtifact.getClassifier());
                     assertEquals(type, translatedArtifact.getExtension());
 
                     found = true;
@@ -120,13 +120,13 @@ public class TestClassifierTypeTranslator extends AbstractDependencyMojoTestCase
         String classifier = "jdk5";
 
         ArtifactTranslator at = new ClassifierTypeTranslator(artifactHandlerManager, classifier, type);
-        Set<ArtifactCoordinate> results = at.translate(artifacts, log);
+        Set<org.eclipse.aether.artifact.Artifact> results = at.translate(artifacts, log);
 
         for (Artifact artifact : artifacts) {
-            Iterator<ArtifactCoordinate> resultIter = results.iterator();
+            Iterator<org.eclipse.aether.artifact.Artifact> resultIter = results.iterator();
             boolean found = false;
             while (!found && resultIter.hasNext()) {
-                ArtifactCoordinate translatedArtifact = resultIter.next();
+                org.eclipse.aether.artifact.Artifact translatedArtifact = resultIter.next();
                 if (artifact.getArtifactId() == translatedArtifact.getArtifactId()
                         && artifact.getGroupId() == translatedArtifact.getGroupId()
                 /* && artifact.getScope() == translatedArtifact.getScope() */ ) {
@@ -146,13 +146,13 @@ public class TestClassifierTypeTranslator extends AbstractDependencyMojoTestCase
         String classifier = "jdk14";
         String type = "sources";
         ArtifactTranslator at = new ClassifierTypeTranslator(artifactHandlerManager, classifier, type);
-        Set<ArtifactCoordinate> results = at.translate(artifacts, log);
+        Set<org.eclipse.aether.artifact.Artifact> results = at.translate(artifacts, log);
 
         for (Artifact artifact : artifacts) {
-            Iterator<ArtifactCoordinate> resultIter = results.iterator();
+            Iterator<org.eclipse.aether.artifact.Artifact> resultIter = results.iterator();
             boolean found = false;
             while (!found && resultIter.hasNext()) {
-                ArtifactCoordinate translatedArtifact = resultIter.next();
+                org.eclipse.aether.artifact.Artifact translatedArtifact = resultIter.next();
                 if (artifact.getArtifactId() == translatedArtifact.getArtifactId()
                         && artifact.getGroupId() == translatedArtifact.getGroupId()) {
                     assertEquals(translatedArtifact.getClassifier(), classifier);
